@@ -33,15 +33,20 @@ def create_new_project(session):
 
     clearConsole()
     num = None
+<<<<<<< HEAD
+
+    if get_yes_no("Do you have a deal number? 💁‍♀️"):
+=======
     dealnumber = None
     deal = None
     if get_yes_no("Do you have a deal number?"):
+>>>>>>> 781162e1d59cabddd9833a2f99424c6f502bf494
         while True:
-            dealnumber = input("Enter deal number: ")
+            dealnumber = input("👀 Enter deal number: ")
             try:
                 int(dealnumber)
             except ValueError:
-                print("Sorry, I didn't understand that? Did you type a number?")
+                print("🤯 Sorry, I didn't understand that? Did you type a number?")
                 continue
             else:
                 if len(dealnumber) == 4:
@@ -63,22 +68,22 @@ def create_new_project(session):
             client = split[3]
             projname = split[4]
 
-    print(f"Ok {session.api_user}, which team are we making a project for?")
+    print(f"👍 Ok {session.api_user}, which team are we making a project for?")
 
     option, index = pick(
         sorted([p["name"] for p in projects if "invoice" not in p["name"]]),
-        "Select the team:",
+        "👬 Select the team:",
         indicator="👉",
     )
 
     clearConsole()
 
     num = get_latest_proj()
-    if get_yes_no(f"Based on the latest X: project, your project number is {num}, u like?"):
-        print(f"Ok, we're rolling with {num}")
+    if get_yes_no(f"🤹‍♂️ Based on the latest X: project, your project number is {num}, u like?"):
+        print(f"🤩 Ok, we're rolling with {num}")
     else:
         while True:
-            raw_input = input("Enter project number: ")
+            raw_input = input("😮 Ok, enter desired project number: ")
             try:
                 int(raw_input)
             except ValueError:
@@ -131,7 +136,11 @@ def create_new_project(session):
 
     if dest_folder is None:
         click.secho(
+<<<<<<< HEAD
+            f"😔 could not find a 'Projects' folder under team {team['name']}", fg="red")
+=======
             f"could not find a 'Projects' folder for team {team['name']}", fg="red")
+>>>>>>> 781162e1d59cabddd9833a2f99424c6f502bf494
         quit()
     if client is None:
         while True:
@@ -196,7 +205,7 @@ def create_new_project(session):
         if template["name"] == "Timetracking_Template":
             timetrack_template = template
 
-    pm_choice, index = pick([m["username"] for m in mgmt], "Select project manager")
+    pm_choice, index = pick([m["username"] for m in mgmt], "👩‍🏫 Select project manager")
     project_manager = mgmt[index]
 
     for task_type in [t["task_type"] for t in production_template["items"]]:
@@ -238,7 +247,7 @@ def create_new_project(session):
         )
 
         if len(project_team) > 1:
-            int_artist = select_artist(project_team, users, "Select INT artist: ")
+            int_artist = select_artist(project_team, users, "👩‍🎨🛋 Select INT artist: ")
         else:
             int_artist = project_team[0]
 
@@ -276,7 +285,7 @@ def create_new_project(session):
         )
 
         if len(project_team) > 1:
-            ext_artist = select_artist(project_team, users, "Select EXT artist: ")
+            ext_artist = select_artist(project_team, users, "👨‍🎨🏞 Select EXT artist: ")
         else:
             ext_artist = project_team[0]
 
@@ -307,8 +316,10 @@ def create_new_project(session):
 
     # using a set here to make sure users aren't added multiple times
     project_set = set()
-    project_set.add(int_artist)
-    project_set.add(ext_artist)
+    if num_int > 0:
+        project_set.add(int_artist)
+    if num_ext > 0:
+        project_set.add(ext_artist)
 
     if internal_project:
         for artist in project_set:
@@ -331,15 +342,19 @@ def create_new_project(session):
                     },
                 )
 
-    drone = get_yes_no("Does the project require photography?")
+    drone = get_yes_no("📸 Does the project require photography?")
 
     session.commit()
 
+<<<<<<< HEAD
+    print(f"✅ Succesfully created {project_name} for {team['name']}")
+=======
     print(f"Succesfully created {project_name} for {team['name']}")
+>>>>>>> 781162e1d59cabddd9833a2f99424c6f502bf494
     if deal is not None:
         print(f"Based on deal {deal}")
     print(f"--- creating objects for {project_name} on ftrack")
-    print(f"--- creating outlook folder for {project_name}")
+    #print(f"--- creating outlook folder for {project_name}")
     print(f"--- creating directory for {project_name} on X:/")
     create_project_on_fileserver(project_name, internal_project, deal)
     print(
